Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: include/core/SkOSFile.h

Issue 384903002: Add file access modes to sk_exists. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Better comment. Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/ports/SkOSFile_none.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/core/SkOSFile.h
diff --git a/include/core/SkOSFile.h b/include/core/SkOSFile.h
index c9fa37ad164c1e46e05d9dd073b3435d33313c3a..1ca11ee932ad19504a1681fee0b162ff2e029f34 100644
--- a/include/core/SkOSFile.h
+++ b/include/core/SkOSFile.h
@@ -77,8 +77,10 @@ bool sk_fidentical(SkFILE* a, SkFILE* b);
*/
int sk_fileno(SkFILE* f);
-// Returns true if something (file, directory, ???) exists at this path.
-bool sk_exists(const char *path);
+/** Returns true if something (file, directory, ???) exists at this path,
+ * and has the specified access flags.
+ */
+bool sk_exists(const char *path, SkFILE_Flags = (SkFILE_Flags)0);
// Returns true if a directory exists at this path.
bool sk_isdir(const char *path);
« no previous file with comments | « no previous file | src/ports/SkOSFile_none.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698